@@ -46,6 +46,7 @@ from .type_defs import (
     GetSiteAddressOutputTypeDef,
     GetSiteOutputTypeDef,
     LineItemRequestTypeDef,
+    ListAssetsOutputTypeDef,
     ListCatalogItemsOutputTypeDef,
     ListOrdersOutputTypeDef,
     ListOutpostsOutputTypeDef,
@@ -227,7 +228,7 @@ class OutpostsClient(BaseClient):
         self, *, OutpostId: str, NextToken: str = ..., MaxResults: int = ...
     ) -> GetOutpostInstanceTypesOutputTypeDef:
         """
-        Lists the instance types for the specified Outpost.
+        Gets the instance types for the specified Outpost.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/outposts.html#Outposts.Client.get_outpost_instance_types)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_outposts/client/#get_outpost_instance_types)
@@ -251,6 +252,21 @@ class OutpostsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_outposts/client/#get_site_address)
         """
 
+    def list_assets(
+        self,
+        *,
+        OutpostIdentifier: str,
+        HostIdFilter: Sequence[str] = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
+    ) -> ListAssetsOutputTypeDef:
+        """
+        Lists the hardware assets in an Outpost.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/outposts.html#Outposts.Client.list_assets)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_outposts/client/#list_assets)
+        """
+
     def list_catalog_items(
         self,
         *,
@@ -261,7 +277,7 @@ class OutpostsClient(BaseClient):
         EC2FamilyFilter: Sequence[str] = ...
     ) -> ListCatalogItemsOutputTypeDef:
         """
-        Use to create a list of every item in the catalog.
+        Lists the items in the catalog.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/outposts.html#Outposts.Client.list_catalog_items)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_outposts/client/#list_catalog_items)
@@ -271,7 +287,7 @@ class OutpostsClient(BaseClient):
         self, *, OutpostIdentifierFilter: str = ..., NextToken: str = ..., MaxResults: int = ...
     ) -> ListOrdersOutputTypeDef:
         """
-        Create a list of the Outpost orders for your Amazon Web Services account.
+        Lists the Outpost orders for your Amazon Web Services account.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/outposts.html#Outposts.Client.list_orders)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_outposts/client/#list_orders)
@@ -287,7 +303,7 @@ class OutpostsClient(BaseClient):
         AvailabilityZoneIdFilter: Sequence[str] = ...
     ) -> ListOutpostsOutputTypeDef:
         """
-        Create a list of the Outposts for your Amazon Web Services account.
+        Lists the Outposts for your Amazon Web Services account.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/outposts.html#Outposts.Client.list_outposts)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_outposts/client/#list_outposts)
@@ -303,7 +319,7 @@ class OutpostsClient(BaseClient):
         OperatingAddressCityFilter: Sequence[str] = ...
     ) -> ListSitesOutputTypeDef:
         """
-        Create a list of the Outpost sites for your Amazon Web Services account.
+        Lists the Outpost sites for your Amazon Web Services account.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/outposts.html#Outposts.Client.list_sites)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_outposts/client/#list_sites)
