@@ -21,6 +21,7 @@ else:
 
 __all__ = (
     "AddressTypeType",
+    "AssetTypeType",
     "CatalogItemClassType",
     "CatalogItemStatusType",
     "FiberOpticCableTypeType",
@@ -47,6 +48,7 @@ __all__ = (
 
 
 AddressTypeType = Literal["OPERATING_ADDRESS", "SHIPPING_ADDRESS"]
+AssetTypeType = Literal["COMPUTE"]
 CatalogItemClassType = Literal["RACK", "SERVER"]
 CatalogItemStatusType = Literal["AVAILABLE", "DISCONTINUED"]
 FiberOpticCableTypeType = Literal["MULTI_MODE", "SINGLE_MODE"]
@@ -143,6 +145,7 @@ ServiceName = Literal[
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-media-pipelines",
     "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
@@ -258,6 +261,7 @@ ServiceName = Literal[
     "iottwinmaker",
     "iotwireless",
     "ivs",
+    "ivschat",
     "kafka",
     "kafkaconnect",
     "kendra",
