@@ -15,8 +15,6 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Mapping, Sequence
 
-from typing_extensions import NotRequired
-
 from .literals import (
     AddressTypeType,
     CatalogItemClassType,
@@ -50,8 +48,10 @@ else:
 
 __all__ = (
     "AddressTypeDef",
+    "AssetInfoTypeDef",
     "CancelOrderInputRequestTypeDef",
     "CatalogItemTypeDef",
+    "ComputeAttributesTypeDef",
     "CreateOrderInputRequestTypeDef",
     "CreateOrderOutputTypeDef",
     "CreateOutpostInputRequestTypeDef",
@@ -76,6 +76,8 @@ __all__ = (
     "InstanceTypeItemTypeDef",
     "LineItemRequestTypeDef",
     "LineItemTypeDef",
+    "ListAssetsInputRequestTypeDef",
+    "ListAssetsOutputTypeDef",
     "ListCatalogItemsInputRequestTypeDef",
     "ListCatalogItemsOutputTypeDef",
     "ListOrdersInputRequestTypeDef",
@@ -132,6 +134,17 @@ class AddressTypeDef(_RequiredAddressTypeDef, _OptionalAddressTypeDef):
     pass
 
 
+AssetInfoTypeDef = TypedDict(
+    "AssetInfoTypeDef",
+    {
+        "AssetId": str,
+        "RackId": str,
+        "AssetType": Literal["COMPUTE"],
+        "ComputeAttributes": "ComputeAttributesTypeDef",
+    },
+    total=False,
+)
+
 CancelOrderInputRequestTypeDef = TypedDict(
     "CancelOrderInputRequestTypeDef",
     {
@@ -153,6 +166,14 @@ CatalogItemTypeDef = TypedDict(
     total=False,
 )
 
+ComputeAttributesTypeDef = TypedDict(
+    "ComputeAttributesTypeDef",
+    {
+        "HostId": str,
+    },
+    total=False,
+)
+
 _RequiredCreateOrderInputRequestTypeDef = TypedDict(
     "_RequiredCreateOrderInputRequestTypeDef",
     {
@@ -416,6 +437,38 @@ LineItemTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredListAssetsInputRequestTypeDef = TypedDict(
+    "_RequiredListAssetsInputRequestTypeDef",
+    {
+        "OutpostIdentifier": str,
+    },
+)
+_OptionalListAssetsInputRequestTypeDef = TypedDict(
+    "_OptionalListAssetsInputRequestTypeDef",
+    {
+        "HostIdFilter": Sequence[str],
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListAssetsInputRequestTypeDef(
+    _RequiredListAssetsInputRequestTypeDef, _OptionalListAssetsInputRequestTypeDef
+):
+    pass
+
+
+ListAssetsOutputTypeDef = TypedDict(
+    "ListAssetsOutputTypeDef",
+    {
+        "Assets": List["AssetInfoTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ListCatalogItemsInputRequestTypeDef = TypedDict(
     "ListCatalogItemsInputRequestTypeDef",
     {
